@@ -1,52 +1,49 @@
 #' Render Markdown to an output format
 #'
 #' Render Markdown to an output format via the \pkg{commonmark} package. The
-#' function \code{mark_html()} is a shorthand of \code{mark(format = 'html',
-#' template = TRUE)}, and \code{mark_latex()} is a shorthand of
-#' \code{mark(format = 'latex', template = TRUE)}.
+#' function `mark_html()` is a shorthand of `mark(format = 'html', template =
+#' TRUE)`, and `mark_latex()` is a shorthand of `mark(format = 'latex', template
+#' = TRUE)`.
 #' @param file Path to an input file. If not provided, it is presumed that the
-#'   \code{text} argument will be used instead. This argument can also take a
+#'   `text` argument will be used instead. This argument can also take a
 #'   character vector of Markdown text directly. To avoid ambiguity in the
-#'   latter case, a single character string input will be treated as a file only
-#'   when the file exists or it has a file extension. If a string happens to
-#'   have a \dQuote{file extension} and should be treated as Markdown text
-#'   instead, wrap it in \code{I()}.
+#'   latter case, a single character string input will be treated as a file if
+#'   the file exists. If a string should be treated as Markdown text when it
+#'   happens to be a file path, wrap it in [I()].
 #' @param output Output file path. If not character, the results will be
 #'   returned as a character vector. If not specified and the input is a file
 #'   path, the output file path will have the same base name as the input file,
-#'   with an extension corresponding to the \code{format} argument, e.g.,
-#'   \code{mark('foo.md', format = 'latex')} will generate an output file
+#'   with an extension corresponding to the `format` argument, e.g.,
+#'   `mark('foo.md', format = 'latex')` will generate an output file
 #'   \file{foo.tex} by default.
 #' @param text A character vector of the Markdown text. By default, it is read
-#'   from \code{file}.
-#' @param format An output format supported by \pkg{commonmark}, e.g.,
-#'   \code{'html'}, \code{'man'}, and \code{'text'}, etc. See the
-#'   \code{\link[commonmark:commonmark]{markdown_*}} renderers in
-#'   \pkg{commonmark}.
-#' @param options Options to be passed to the renderer. See
-#'   \code{\link{markdown_options}()} for details. This argument can take either
-#'   a character vector of the form \code{"+option1 option2-option3"} (use
-#'   \code{+} or a space to enable an option, and \code{-} to disable an
-#'   option), or a list of the form \code{list(option1 = value1, option2 =
-#'   value2, ...)}. A string \code{"+option1"} is equivalent to
-#'   \code{list(option1 = TRUE)}, and \code{"-option2"} means \code{list(option2
-#'   = FALSE)}. Options that do not take logical values must be specified via a
-#'   list, e.g., \code{list(width = 30)}.
+#'   from `file`.
+#' @param format An output format supported by \pkg{commonmark}, e.g., `'html'`,
+#'   `'man'`, and `'text'`, etc. See the
+#'   [`markdown_*()`][commonmark::commonmark] renderers in \pkg{commonmark}.
+#' @param options Options to be passed to the renderer. See [markdown_options()]
+#'   for details. This argument can take either a character vector of the form
+#'   `"+option1 option2-option3"` (use `+` or a space to enable an option, and
+#'   `-` to disable an option), or a list of the form `list(option1 = value1,
+#'   option2 = value2, ...)`. A string `"+option1"` is equivalent to
+#'   `list(option1 = TRUE)`, and `"-option2"` means `list(option2 = FALSE)`.
+#'   Options that do not take logical values must be specified via a list, e.g.,
+#'   `list(width = 30)`.
 #' @param template Path to a template file. The default value is
-#'   \code{getOption('markdown.FORMAT.template',
-#'   markdown:::pkg_file('resources', 'markdown.FORMAT'))} where \code{FORMAT}
-#'   is the output format name (\code{html} or \code{latex}). It can also take a
-#'   logical value: \code{TRUE} means to use the default template, and
-#'   \code{FALSE} means to generate only a fragment without using any template.
+#'   `getOption('markdown.FORMAT.template', markdown:::pkg_file('resources',
+#'   'markdown.FORMAT'))` where `FORMAT` is the output format name (`html` or
+#'   `latex`). It can also take a logical value: `TRUE` means to use the default
+#'   template, and `FALSE` means to generate only a fragment without using any
+#'   template.
 #' @param meta A named list of metadata. Elements in the metadata will be used
-#'   to fill out the template by their names and values, e.g., \code{list(title
-#'   = ...)} will replace the \code{$title$} variable in the template. See the
-#'   Section \dQuote{YAML metadata} in the vignette \code{vignette('intro',
-#'   package = 'markdown')} for supported variables.
-#' @return Invisible \code{NULL} when output is to a file, otherwise a character
+#'   to fill out the template by their names and values, e.g., `list(title =
+#'   ...)` will replace the `$title$` variable in the template. See the Section
+#'   \dQuote{YAML metadata} in the vignette `vignette('intro', package =
+#'   'markdown')` for supported variables.
+#' @return Invisible `NULL` when output is to a file, otherwise a character
 #'   vector of the rendered output.
 #' @seealso The spec of GitHub Flavored Markdown:
-#'   \url{https://github.github.com/gfm/}
+#'   <https://github.github.com/gfm/>
 #' @import utils
 #' @export
 #' @examples
@@ -55,7 +52,7 @@
 #' # a few corner cases
 #' mark(character(0))
 #' mark('')
-#' # if input looks like file but should be treated as text, use I()
+#' # if input happens to be a file path but should be treated as text, use I()
 #' mark(I('This is *not* a file.md'))
 #' # that's equivalent to
 #' mark(text = 'This is *not* a file.md')
@@ -147,7 +144,7 @@ mark = function(
   if (has_sup <- test_feature('superscript', r2)) {
     id2 = id_string(text)
     find_prose()
-    text[p] = match_replace(text[p], r2, perl = TRUE, function(x) {
+    text[p] = match_replace(text[p], r2, function(x) {
       # place superscripts inside !id...id!
       x = gsub('^\\^|\\^$', id2, x)
       sprintf('!%s!', x)
@@ -157,7 +154,7 @@ mark = function(
   if (has_sub <- test_feature('subscript', r3)) {
     id3 = id_string(text)
     find_prose()
-    text[p]= match_replace(text[p], r3, perl = TRUE, function(x) {
+    text[p]= match_replace(text[p], r3, function(x) {
       # place subscripts inside !id...id!
       x = gsub('^~|~$', id3, x)
       sprintf('!%s!', x)
@@ -166,7 +163,7 @@ mark = function(
   # disallow single tilde for <del> (I think it is an awful idea in GFM's
   # strikethrough extension to allow both single and double tilde for <del>)
   find_prose()
-  text[p] = match_replace(text[p], r3, perl = TRUE, function(x) {
+  text[p] = match_replace(text[p], r3, function(x) {
     gsub('^~|~$', '\\\\~', x)
   })
   # add line breaks before/after fenced Div's to wrap ::: tokens into separate
@@ -214,7 +211,7 @@ mark = function(
       # discard other types of raw content blocks
       x[!(i1 | i2)] = ''
       x
-    })
+    }, perl = FALSE)
     # commonmark doesn't support ```{.class}, which should be treated as ```class
     ret = gsub('(<pre><code class="language-)\\{[.]([^}]+)}(">)', '\\1\\2\\3', ret)
     # auto identifiers
@@ -252,7 +249,7 @@ mark = function(
       # TODO: support code highlighting for latex (listings or highr::hi_latex)
       x = gsub(r4, '\\1\\3\\4', x)
       x
-    })
+    }, perl = FALSE)
     # fix horizontal rules from --- (\linethickness doesn't work)
     ret = gsub('{\\linethickness}', '{1pt}', ret, fixed = TRUE)
     ret = redefine_level(ret, options[['top_level']])
@@ -267,7 +264,7 @@ mark = function(
 
   if (format == 'html') {
     ret = xfun::in_dir(
-      if (is_file(file, TRUE)) dirname(file) else '.',
+      if (is_file(file)) dirname(file) else '.',
       embed_resources(ret, options[['embed_resources']])
     )
     ret = clean_html(ret)
@@ -281,7 +278,7 @@ mark = function(
 }
 
 #' @rdname mark
-#' @param ... Arguments to be passed to \code{mark()}.
+#' @param ... Arguments to be passed to `mark()`.
 #' @export
 #' @examples
 #'
@@ -354,11 +351,11 @@ tpl_html = function(x) {
 #' Markdown rendering options
 #'
 #' A list of all options to control Markdown rendering. Options that are enabled
-#' by default are marked by a \code{+} prefix, and those disabled by default are
-#' marked by \code{-}.
+#' by default are marked by a `+` prefix, and those disabled by default are
+#' marked by `-`.
 #'
-#' See \code{vignette('intro', package = 'markdown')} for the full list of
-#' options and their documentation.
+#' See `vignette('intro', package = 'markdown')` for the full list of options
+#' and their documentation.
 #' @return A character vector of all available options.
 #' @export
 #' @examples
